#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-L/usr/pkg/lib"
XSLT_LIBS="-lxslt -L/usr/pkg/lib -L/usr/pkg/lib -lxml2 "
XSLT_PRIVATE_LIBS=""
XSLT_INCLUDEDIR="-I/usr/pkg/include"
MODULE_VERSION="xslt-1.1.43"
